@@ -7,9 +7,14 @@ Based on Rich Text Format (RTF) Compression Algorithm
 https://msdn.microsoft.com/en-us/library/cc463890(v=exchg.80).aspx
 """
 
-__title__ = 'compressed_rtf'
-__version__ = '1.0.6'
-__author__ = 'Dmitry Alimov'
-__license__ = 'MIT'
+from .__version__ import (
+    __author__,
+    __description__,
+    __license__,
+    __long_description__,
+    __title__,
+    __url__,
+    __version__,
+)
 
 from .compressed_rtf import compress, decompress
